@@ -2,8 +2,9 @@ pub use self::configuration::RapierConfiguration;
 pub use self::context::RapierContext;
 pub use self::plugin::{NoUserData, RapierPhysicsPlugin};
 
+pub mod systems;
+
 mod configuration;
 mod context;
 mod narrow_phase;
 mod plugin;
-pub(crate) mod systems;
